#!/bin/bash

#
# guess the DNS domainname:
# if dnsdomainname gives something sensible, use it
#    exludes "localdomain" and similar, should have a "."
# otherwise try to guess based on the IP on the "default gateway" interface
# may fail completely e.g. for NATed machines on a private network
#   we could use "traceroute" to discover this, but why bother?

export LANG=C

guess_default_if_name() {
  local defdev_tmp=$(ip route show scope global)
  local defdev=${defdev_tmp##default via*dev }

  if [ -z "$defdev" ]; then
    return 1
  fi

  local def_ip_tmp1=$(ip -o -f inet addr show scope global dev ${defdev})
  local def_ip_tmp2=${def_ip_tmp1%%/?? brd*}
  local def_ip=${def_ip_tmp2##*inet }

  if [ -z "$def_ip" -o -n "${def_ip//*.*.*.*}" ]; then
    return 1
  fi

  local def_name_tmp1=$(host ${def_ip})
  local def_name_tmp2=${def_name_tmp1##*pointer }
  def_name=${def_name_tmp2%%.}
  if [ "$def_name" != "${def_name//Host*not found*}" ]; then
     def_name=''
     return 1
  fi

  # special and unfortunate hack for the CERN Technical Network
  case "$def_ip" in
      172.18.*)
	 def_name=somewhere.tn.cern.ch
         ;;
  esac
  #$def_name
}


dnsdom=$(dnsdomainname)
guess_default_if_name
if [ -n "$def_name" ]; then
  dom=${def_name#*.}
elif [ -n "$dnsdom" -a -z "${dnsdom//*.*}" ]; then
  dom="$dnsdom"
else
  # tough luck
  dom=""
fi

echo "$dom"




